Learn R Programming

puzzle (version 0.0.1)

df_extra_times_parent_evid4: An extra times parent data set to be used with EVID=4.

Description

A dataset containing extra times for an hypothetical parent drug.

Usage

df_extra_times_parent_evid4

Arguments

Format

A data frame with 770 rows and 3 variable:

PERIOD

Period

TIMEPOINT

Timepoint

TIME

Time, in hours